@@ -2,7 +2,7 @@
  *            dvarchive.c
  *
  *  Tue Aug  1 00:50:52 2006
- *  Copyright  2006  Neil Williams
+ *  Copyright  2006, 2007  Neil Williams
  *  linux@codehelp.co.uk
  * Copyright (C) 1994,1995 Ian Jackson <ian@chiark.greenend.org.uk>
  *******************************************************************/
@@ -32,6 +32,7 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <glib/gstdio.h>
+#include <libgnomevfs/gnome-vfs.h>
 #include <gtk/gtk.h>
 #include <ar.h>
 #include <archive.h>
@@ -40,10 +41,11 @@
 #include "dvpreview.h"
 #include "callbacks.h"
 #include "support.h"
+#include "interface.h"
 #include "dvarchive.h"
 
 #define BLOCKSIZE 10240
-#define MAXGZ 1024*1024*sizeof(gint)
+#define MAXGZ 1024*512*sizeof(gint)
 
 typedef enum
 {
@@ -82,13 +84,14 @@ struct DV_s
 	struct archive *data_tar;
 	struct ar_hdr *current;
 	gulong skip;
-	FILE *pkg;
+	GnomeVFSHandle * vfshandle;
 	GtkWidget *parent;
 	DVError error;
 	gboolean store_set;
 	GList * subwindows;
 	const gchar * ar_message; /* error string from archive/ar_hdr */
 	gchar * selected_file;
+	gchar * current_path;
 };
 
 enum compression_type
@@ -100,14 +103,67 @@ dv_create (void)
 	DVContents *deb;
 
 	deb = g_new0 (DVContents, 1);
-	deb->control_files = 
-		g_hash_table_new (g_str_hash, g_str_equal);
-	deb->data_files = 
-		g_hash_table_new (g_str_hash, g_str_equal);
+	deb->control_files = g_hash_table_new (g_str_hash, g_str_equal);
+	deb->data_files = g_hash_table_new (g_str_hash, g_str_equal);
 	deb->subwindows = NULL;
 	return deb;
 }
 
+static void
+dv_new_window (const gchar * debname)
+{
+	DVContents * context;
+	GtkWindow *window1;
+
+	g_return_if_fail (debname);
+	context = dv_create();
+	window1 = GTK_WINDOW(create_deb_gview_window ());
+	g_return_if_fail (window1);
+	g_object_set_data (G_OBJECT(window1), DVCONTENTS, context);
+	set_dv_parent (GTK_WIDGET(window1));
+	set_deb_file (debname, context);
+	gtk_widget_show (GTK_WIDGET(window1));
+	dv_add_child (window1);
+}
+
+void
+dv_parse_changes (const gchar * cfilename)
+{
+	gchar **changes_file;
+	gchar * debname, *debline, *contents, *chgpath;
+	guint c;
+	gchar *vfstext;
+	GnomeVFSURI * vfsuri;
+	GnomeVFSResult vfsresult;
+	gint changes_size;
+
+	g_return_if_fail (cfilename);
+	vfstext = gnome_vfs_make_uri_from_input (cfilename);
+	vfsuri = gnome_vfs_uri_new (vfstext);
+	chgpath = gnome_vfs_uri_to_string
+		(gnome_vfs_uri_resolve_relative(vfsuri, "./"), GNOME_VFS_URI_HIDE_NONE);
+	vfsresult = gnome_vfs_read_entire_file (vfstext, &changes_size, &contents);
+	gnome_vfs_uri_unref (vfsuri);
+	changes_file = g_strsplit (contents, "\n", -1);
+	for (c = 0; c < g_strv_length(changes_file); c++)
+	{
+		debline = NULL;
+		debname = NULL;
+		debline = g_strrstr (changes_file[c], ".deb");
+		if (debline)
+		{
+			gchar * partial;
+			partial = g_strstrip (g_strrstr (changes_file[c], " "));
+			if (g_str_has_suffix (chgpath, "/"))
+				debname = g_strconcat (chgpath, partial, NULL);
+			else
+				debname = g_strconcat(chgpath, "/", partial, NULL);
+			if (g_str_has_suffix (debname, ".deb"))
+				dv_new_window (debname);
+		}
+	}
+}
+
 void
 dv_archive_clear (DVContents *deb)
 {
@@ -115,14 +171,12 @@ dv_archive_clear (DVContents *deb)
 	if (deb->control_files)
 	{
 		g_hash_table_destroy (deb->control_files);
-		deb->control_files = 
-			g_hash_table_new (g_str_hash, g_str_equal);
+		deb->control_files = g_hash_table_new (g_str_hash, g_str_equal);
 	}
 	if (deb->data_files)
 	{
 		g_hash_table_destroy (deb->data_files);
-		deb->data_files = 
-			g_hash_table_new (g_str_hash, g_str_equal);
+		deb->data_files = g_hash_table_new (g_str_hash, g_str_equal);
 	}
 	if (deb->copyright)
 		g_free (deb->copyright);
@@ -168,6 +222,20 @@ dv_get_selected_file (DVContents * deb)
 	return deb->selected_file;
 }
 
+gchar *
+dv_get_working_path (DVContents * deb)
+{
+	g_return_val_if_fail (deb, NULL);
+	return deb->current_path;
+}
+
+void
+dv_set_working_path (DVContents * deb, gchar * path)
+{
+	g_return_if_fail (deb);
+	deb->current_path = g_strdup (path);
+}
+
 static void
 dv_show_error (DVError dve, GtkWidget * widget)
 {
@@ -222,8 +290,7 @@ dv_show_error (DVError dve, GtkWidget * widget)
 	if (deb->ar_message)
 		fmt = g_strconcat (fmt, "\n", deb->ar_message, NULL);
 	dialog = GTK_DIALOG (gtk_message_dialog_new (GTK_WINDOW(parent),
-			GTK_DIALOG_DESTROY_WITH_PARENT,
-			GTK_MESSAGE_ERROR,
+			GTK_DIALOG_DESTROY_WITH_PARENT,	GTK_MESSAGE_ERROR,
 			GTK_BUTTONS_CLOSE, _("Error loading file '%s'. %s"),
 			deb->filename, fmt));
 	deb->ar_message = NULL;
@@ -245,6 +312,9 @@ set_deb_file (const gchar * filename, DVContents *deb)
 		dv_show_error (DV_ERR_NO_FILE, deb->parent);
 		return;
 	}
+	if ((!g_str_has_suffix(filename, ".deb")) &&
+		(!g_str_has_suffix(filename, ".udeb")))
+		return;
 	deb->filename = filename;
 }
 
@@ -252,45 +322,41 @@ static gint
 dv_archive_open (struct archive *a, gpointer client_data)
 {	
 	DVContents *d = (DVContents*)client_data;
+	gchar *size;
 
 	g_return_val_if_fail (d, ARCHIVE_FATAL);
 	g_return_val_if_fail (d->readbuffer == NULL, ARCHIVE_FATAL);
 	/* deb->pkg already open */
-	{
-		gchar *size;
-		d->skip = 0;
-		size = g_strndup (d->current->ar_size, 10);
-		d->skip = g_ascii_strtod (size, NULL);
-		g_free (size);
-		d->readbuffer = malloc (d->skip);
-	}
+	d->skip = 0;
+	size = g_strndup (d->current->ar_size, 10);
+	d->skip = g_ascii_strtod (size, NULL);
+	g_free (size);
+	d->readbuffer = malloc (d->skip);
 	if( d->readbuffer == NULL ) {
 		archive_set_error(a, ENOMEM, _("Out of memory."));
 		d->ar_message = archive_error_string (a);
 		return ARCHIVE_FATAL;
 	}
-	return 0;
+	return ARCHIVE_OK;
 }
-struct read_memory_data {
-        gpointer buffer;
-        size_t   size;
-};
 
 static ssize_t
 dv_archive_read (struct archive *a, gpointer client_data,
 	gconstpointer *buffer)
 {
-	ssize_t bytesread;
-	DVContents *d = (DVContents*)client_data;
+	GnomeVFSFileSize bytesread;
+	GnomeVFSResult result;
 
+	DVContents *d = (DVContents*)client_data;
 	g_return_val_if_fail (d, DV_AR_FAIL);
 	*buffer = d->readbuffer;
 	g_return_val_if_fail (d->readbuffer != NULL, DV_AR_FAIL);
 	if (d->skip == 0)
-		return 0;
-	bytesread = fread (d->readbuffer, 1, d->skip, d->pkg);
-	if (bytesread < 0)
+		return ARCHIVE_OK;
+	result = gnome_vfs_read (d->vfshandle, d->readbuffer, d->skip, &bytesread);
+	if (result != GNOME_VFS_OK)
 	{
+		g_warning ("VFS read error:%s", gnome_vfs_result_to_string (result));
 		archive_set_error (a, errno, 
 			_("Error reading from file: %m"));
 		d->ar_message = archive_error_string (a);
@@ -309,9 +375,10 @@ dv_archive_read (struct archive *a, gpointer client_data,
 	return bytesread;
 }
 
+/* A .deb is two archives within an archive so do NOT
+close the FILE or GnomeVFSHandle at this stage! */
 static gint
-dv_archive_close (struct archive *r __attribute__ ((unused)),
-				  gpointer client_data)
+dv_archive_close (struct archive *r __attribute__ ((unused)), gpointer client_data)
 {
 	DVContents *d = (DVContents*)client_data;
 
@@ -343,29 +410,44 @@ parseheaderlength (const gchar *inh, size_t len)
 void
 prepare_contents (const gchar * filename, DVContents * deb)
 {
-	gint memberlen, error_num;
-	gchar *infobuf;
+	GnomeVFSFileSize bytesread, header;
+	GnomeVFSURI * vfs_uri;
+	GnomeVFSResult result;
+	GnomeVFSFileOffset seek;
 	struct ar_hdr debian_binary;
 	struct ar_hdr controlgz;
 	struct ar_hdr datagz;
-	gchar versionbuf[40];
+	gint memberlen, error_num;
+	gulong bytes_left;
+	gchar * versionbuf, * vers_cmp, *infobuf;
 
 	g_return_if_fail (deb);
-	deb->pkg = fopen (filename, "r");
-	if (!deb->pkg)
+	vfs_uri = gnome_vfs_uri_new (gnome_vfs_make_uri_from_shell_arg (filename));
+	if (!gnome_vfs_uri_exists (vfs_uri))
 	{
 		dv_show_error (DV_ERR_FILE_READ, deb->parent);
-		fclose (deb->pkg);
 		return;
 	}
-	if ((!fgets (versionbuf, sizeof (versionbuf), deb->pkg)) ||
-		(strcmp (versionbuf, ARMAG)))
+	result = gnome_vfs_open_uri (&deb->vfshandle, vfs_uri, GNOME_VFS_OPEN_READ);
+	if (result != GNOME_VFS_OK)
+	{
+		dv_show_error (DV_ERR_FILE_READ, deb->parent);
+		g_warning ("VFS open error: %s", gnome_vfs_result_to_string (result));
+		gnome_vfs_close (deb->vfshandle);
+		return;
+	}
+	versionbuf = g_new0 (gchar, strlen(ARMAG) + 1);
+	gnome_vfs_read (deb->vfshandle, versionbuf, strlen(ARMAG), &bytesread);
+	vers_cmp = g_strndup (versionbuf, strlen(ARMAG));
+	g_free (versionbuf);
+	if (strcmp(vers_cmp, ARMAG))
 	{
 		dv_show_error (DV_ERR_VERSION, deb->parent);
-		fclose (deb->pkg);
+		gnome_vfs_close (deb->vfshandle);
 		return;
 	}
-	fread (&debian_binary, 1, sizeof (struct ar_hdr), deb->pkg);
+	header = sizeof(struct ar_hdr);
+	gnome_vfs_read (deb->vfshandle, &debian_binary, header, &bytesread);
 	if (memcmp (debian_binary.ar_name, "debian-binary   ",
 			sizeof (debian_binary.ar_name)) &&
 		memcmp (debian_binary.ar_name, "debian-binary/   ",
@@ -373,13 +455,16 @@ prepare_contents (const gchar * filename, DVContents * deb)
 	{
 		dv_show_error (DV_ERR_NOT_DPKG, deb->parent);
 	}
-	memberlen = parseheaderlength (debian_binary.ar_size,
+	memberlen = parseheaderlength (debian_binary.ar_size, 
 		sizeof (debian_binary.ar_size));
 	if (!memberlen)
 		dv_show_error (DV_ERR_CORRUPT_FILE, deb->parent);
-	infobuf = malloc (memberlen + 1);
-	fread (infobuf, 1, memberlen + (memberlen & 1), deb->pkg);
-	fread (&controlgz, 1, sizeof (struct ar_hdr), deb->pkg);
+	header = memberlen + 1;
+	infobuf = g_new0(gchar, header);
+	gnome_vfs_read (deb->vfshandle, infobuf, memberlen + (memberlen & 1), &bytesread);
+	g_free (infobuf);
+	header = sizeof(struct ar_hdr);
+	gnome_vfs_read (deb->vfshandle, &controlgz, header, &bytesread);
 	deb->current = &controlgz;
 	deb->control_tar = archive_read_new ();
 	archive_read_support_compression_gzip (deb->control_tar);
@@ -391,7 +476,7 @@ prepare_contents (const gchar * filename, DVContents * deb)
 	{
 		dv_show_error (DV_ERR_CORRUPT_FILE, deb->parent);
 		deb->ar_message = archive_error_string (deb->control_tar);
-		fclose (deb->pkg);
+		gnome_vfs_close (deb->vfshandle);
 		return;
 	}
 	else
@@ -402,8 +487,7 @@ prepare_contents (const gchar * filename, DVContents * deb)
 		gint64 size;
 		DVFileData *dvfd;
 
-		while (archive_read_next_header (deb->control_tar, 
-			&entry) == ARCHIVE_OK)
+		while (archive_read_next_header (deb->control_tar, &entry) == ARCHIVE_OK)
 		{
 			size = archive_entry_size (entry);
 			locate = g_strdup (archive_entry_pathname (entry));
@@ -412,10 +496,9 @@ prepare_contents (const gchar * filename, DVContents * deb)
 			dvfd = g_new0 (DVFileData, 1);
 			dvfd->size = size;
 			if(S_ISREG(archive_entry_mode(entry)))
-			dvfd->content = content;
+				dvfd->content = content;
 			dvfd->compressed = FALSE;
-			g_hash_table_insert (deb->control_files, 
-				locate, dvfd);
+			g_hash_table_insert (deb->control_files, locate, dvfd);
 			if ((0 == strcmp (locate, "./control")) ||
 				(0 == strcmp (locate, "control")))
 			{
@@ -424,36 +507,38 @@ prepare_contents (const gchar * filename, DVContents * deb)
 
 				/* todo: pattern match Package: Version: for
 				title of window.*/
-				display_area = lookup_widget 
-					(deb->parent, "display");
-				buffer =
-					gtk_text_view_get_buffer (GTK_TEXT_VIEW
-					(display_area));
+				display_area = lookup_widget (deb->parent, "display");
+				buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW(display_area));
 				gtk_text_buffer_set_text (buffer, (gchar*)content, -1);
-				gtk_text_view_set_buffer (GTK_TEXT_VIEW 
-					(display_area),	buffer);
+				gtk_text_view_set_buffer (GTK_TEXT_VIEW (display_area),	buffer);
 			}
 			archive_read_data_skip (deb->control_tar);
 		}
 	}
 	dv_archive_close (deb->control_tar, deb);
+	bytes_left = strtoul(controlgz.ar_size,NULL,10);
+	/* if the size of control.tar.gz is odd,
+	seek one byte to the start of data.tar.gz */
+	seek = (bytes_left & 1);
+	if (seek > 0)
 	{
-		/* if the size of control.tar.gz is odd,
-		seek one byte to the start of data.tar.gz */
-		gulong bytes_left;
-		off_t s;
-		gint seek;
-		bytes_left = strtoul(controlgz.ar_size,NULL,10);
-		seek = (bytes_left & 1);
-		s = fseek(deb->pkg,seek,SEEK_CUR);
-		if( s == (off_t)-1 ) {
+		gpointer dump;
+		dump = g_new0(gchar, seek);
+		/* seek doesn't appear to work well in VFS so read into a dump instead. */
+		result = gnome_vfs_read (deb->vfshandle, dump, seek, &bytesread);
+		g_free (dump);
+		if (result != GNOME_VFS_OK) {
 			dv_show_error (DV_ERR_CORRUPT_FILE, deb->parent);
 			deb->ar_message = archive_error_string (deb->control_tar);
-			fclose (deb->pkg);
+			gnome_vfs_close (deb->vfshandle);
 			return;
 		}
 	}
-	fread (&datagz, 1, sizeof (struct ar_hdr), deb->pkg);
+	header = sizeof(struct ar_hdr);
+	result = gnome_vfs_read (deb->vfshandle, &datagz, header, &bytesread);
+	if (result != GNOME_VFS_OK)
+		g_warning ("VFS data tarball read error: %s", 
+		gnome_vfs_result_to_string (result));
 	deb->current = &datagz;
 	deb->data_tar = archive_read_new ();
 	archive_read_support_compression_gzip (deb->data_tar);
@@ -469,19 +554,16 @@ prepare_contents (const gchar * filename, DVContents * deb)
 	else
 	{
 		struct archive_entry *entry;
-		gpointer *content;
+		gpointer *datacontent;
 		gint64 size;
 		gchar *locate;
 		DVFileData *dvfd;
 
-		content = NULL;
-		size = 0;
-		while (archive_read_next_header (deb->data_tar, &entry) ==
-			ARCHIVE_OK)
+		while (archive_read_next_header (deb->data_tar, &entry) == ARCHIVE_OK)
 		{
 			size = archive_entry_size (entry);
-			content = g_new0 (gpointer, size);
-			archive_read_data (deb->data_tar, content, size);
+			datacontent = g_new0 (gpointer, size);
+			archive_read_data (deb->data_tar, datacontent, size);
 			/* locate is the name of the .gz file */
 			locate = g_strdup (archive_entry_pathname (entry));
 			dvfd = g_new0 (DVFileData, 1);
@@ -492,10 +574,8 @@ prepare_contents (const gchar * filename, DVContents * deb)
 				gint err;
 				gzFile t;
 				gpointer h;
-				gint f = g_file_open_tmp ("dvXXXXXX", 
-					&temp_file, NULL);
-				g_file_set_contents (temp_file, (gchar*)content, 
-					size, NULL);
+				gint f = g_file_open_tmp ("dvXXXXXX", &temp_file, NULL);
+				g_file_set_contents (temp_file, (gchar*)datacontent, size, NULL);
 				close (f);
 				h = g_new0 (gpointer, MAXGZ);
 				t = gzopen (temp_file, "rb");
@@ -513,18 +593,17 @@ prepare_contents (const gchar * filename, DVContents * deb)
 			{
 				if (g_str_has_suffix (locate, "copyright"))
 				{
-					g_hash_table_insert (deb->control_files, 
-						"./copyright", dvfd);
-					deb->copyright = g_strdup ((gchar*)content);
+					g_hash_table_insert (deb->control_files, "./copyright", dvfd);
+					deb->copyright = g_strdup ((gchar*)datacontent);
 				}
-				dvfd->content = content;
+				dvfd->content = datacontent;
 			}
 			g_hash_table_insert (deb->data_files, locate, dvfd);
 			archive_read_data_skip (deb->data_tar);
 		}
 		archive_read_finish (deb->data_tar);
 	}
-	fclose (deb->pkg);
+	gnome_vfs_close (deb->vfshandle);
 }
 
 static void
@@ -538,8 +617,7 @@ add_control_files (gpointer key, gpointer value, gpointer user_data)
 	if (g_str_has_suffix(path, "/"))
 		return;
 	size_str = g_strdup_printf ("%" G_GINT64_FORMAT, dvfd->size);
-	gtk_tree_store_append (dvi->store, dvi->child_iter, 
-		dvi->parent_iter);
+	gtk_tree_store_append (dvi->store, dvi->child_iter, dvi->parent_iter);
 	gtk_tree_store_set (dvi->store, dvi->child_iter, PKG_COLUMN,
 		g_filename_to_utf8 ((gchar*)key, -1, NULL, NULL, NULL),
 		SIZE_COLUMN, size_str, LOCATION_COLUMN,
@@ -558,8 +636,7 @@ add_data_files (gpointer key, gpointer value, gpointer user_data)
 	if (g_str_has_suffix(path, "/"))
 		return;
 	size_str = g_strdup_printf ("%" G_GINT64_FORMAT, dvfd->size);
-	gtk_tree_store_append (dvi->store, dvi->child_iter, 
-		dvi->parent_iter);
+	gtk_tree_store_append (dvi->store, dvi->child_iter, dvi->parent_iter);
 	gtk_tree_store_set (dvi->store, dvi->child_iter, PKG_COLUMN,
 		g_filename_to_utf8 (file, -1, NULL, NULL, NULL),
 		SIZE_COLUMN, size_str, LOCATION_COLUMN,
@@ -594,8 +671,7 @@ columns_reset (gpointer value, gpointer user_data)
 }
 
 static gint
-size_compare (GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b,
- 		gpointer user_data)
+size_compare (GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer user_data)
 {
 	gint result;
 	gchar *str_a, *str_b;
@@ -636,6 +712,17 @@ tree_selection_changed_cb (GtkTreeSelection *selection, gpointer data)
 	}
 }
 
+static void
+dv_update_title (const gchar * filename, DVContents * deb)
+{
+	const gchar * current;
+	gchar * newstr;
+
+	current = _("Debian package file viewer");
+	newstr = g_strconcat (filename, " - ", current, NULL);
+	gtk_window_set_title (GTK_WINDOW(deb->parent), newstr);
+}
+
 void
 open_deb (const gchar * filename, DVContents * deb)
 {
@@ -649,20 +736,22 @@ open_deb (const gchar * filename, DVContents * deb)
 	GtkTreeViewColumn *column;
 	GtkTreeSelection *select;
 	DVIter dvi;
-	struct stat statinfo;
-	gint stat_val;
+	GnomeVFSFileInfo *vfsinfo;
+	GnomeVFSResult vfsresult;
 
 	g_return_if_fail (deb);
 	if (!filename)
 		return;
-	stat_val = g_stat (filename, &statinfo);
-	deb->filename = filename;
-	if (!S_ISREG (statinfo.st_mode) || statinfo.st_size == 0)
+	vfsinfo = gnome_vfs_file_info_new ();
+	vfsresult = gnome_vfs_get_file_info (filename, vfsinfo, 
+		GNOME_VFS_FILE_INFO_DEFAULT);
+	if ((vfsinfo->type != GNOME_VFS_FILE_TYPE_REGULAR) || (vfsinfo->size == 0))
 	{
 		dv_show_error (DV_ERR_NO_FILE, deb->parent);
 		return;
 	}
 	prepare_contents (filename, deb);
+	dv_update_title(filename, deb);
 	treeview = lookup_widget (deb->parent, "treeview");
 	g_return_if_fail (treeview);
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW(treeview));
@@ -672,17 +761,15 @@ open_deb (const gchar * filename, DVContents * deb)
 		store = GTK_TREE_STORE (model);
 		sort = GTK_TREE_SORTABLE(store);
 		gtk_tree_store_clear (store);
-		columns = gtk_tree_view_get_columns 
-			(GTK_TREE_VIEW(treeview));
+		columns = gtk_tree_view_get_columns (GTK_TREE_VIEW(treeview));
 		g_list_foreach (columns, columns_reset, treeview);
 	}
 	else
 	{
-		store = gtk_tree_store_new (N_COLUMNS,
-			G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
+		store = gtk_tree_store_new (N_COLUMNS, G_TYPE_STRING, 
+			G_TYPE_STRING, G_TYPE_STRING);
 		sort = GTK_TREE_SORTABLE(store);
-		gtk_tree_view_set_model (GTK_TREE_VIEW (treeview),
-			GTK_TREE_MODEL (sort));
+		gtk_tree_view_set_model (GTK_TREE_VIEW (treeview), GTK_TREE_MODEL (sort));
 		deb->store_set = TRUE;
 	}
 	gtk_tree_store_append (store, &parent_iter, NULL);
@@ -691,13 +778,13 @@ open_deb (const gchar * filename, DVContents * deb)
 	renderer = gtk_cell_renderer_text_new ();
 	column = gtk_tree_view_column_new_with_attributes
 		(_("Package"), renderer, "text", PKG_COLUMN, NULL);
+	gtk_tree_sortable_set_sort_column_id (sort, PKG_COLUMN, GTK_SORT_ASCENDING);
 	gtk_tree_view_column_set_sort_column_id (column, PKG_COLUMN);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 	column = gtk_tree_view_column_new_with_attributes
 		(_("Size"), renderer, "text", SIZE_COLUMN, NULL);
 	gtk_tree_view_column_set_sort_column_id (column, SIZE_COLUMN);
-	gtk_tree_sortable_set_sort_func (sort, SIZE_COLUMN, size_compare,
-		NULL, NULL);
+	gtk_tree_sortable_set_sort_func (sort, SIZE_COLUMN, size_compare, NULL, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 	column = gtk_tree_view_column_new_with_attributes
 		(_("Location"), renderer, "text", LOCATION_COLUMN, NULL);
@@ -705,8 +792,7 @@ open_deb (const gchar * filename, DVContents * deb)
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 	gtk_tree_store_append (store, &deb_iter, &parent_iter);
 	gtk_tree_store_set (store, &deb_iter, PKG_COLUMN,
-		_("Debian data"), SIZE_COLUMN, NULL, LOCATION_COLUMN, 
-		NULL, -1);
+		_("Debian data"), SIZE_COLUMN, NULL, LOCATION_COLUMN, NULL, -1);
 	dvi.store = store;
 	dvi.child_iter = &file_iter;
 	dvi.parent_iter = &deb_iter;
@@ -722,8 +808,8 @@ open_deb (const gchar * filename, DVContents * deb)
 	gtk_tree_view_expand_all (GTK_TREE_VIEW(treeview));
 	select = gtk_tree_view_get_selection (GTK_TREE_VIEW (treeview));
 	gtk_tree_selection_set_mode (select, GTK_SELECTION_SINGLE);
-	g_signal_connect (G_OBJECT (select), "changed",
-					  G_CALLBACK (tree_selection_changed_cb), deb);
+	g_signal_connect (G_OBJECT (select), "changed", 
+		G_CALLBACK (tree_selection_changed_cb), deb);
 	gtk_widget_show_all (treeview);
 }
 
@@ -753,13 +839,11 @@ dv_get_control_content (const gchar * file, GtkWidget * widget)
 		guint s_id;
 		GtkWidget *sbar;
 		sbar = lookup_widget(GTK_WIDGET(widget), "dvstatusbar");
-		s_id = gtk_statusbar_get_context_id (GTK_STATUSBAR(sbar), 
-			"errors");
+		s_id = gtk_statusbar_get_context_id (GTK_STATUSBAR(sbar), "errors");
 		gtk_statusbar_pop (GTK_STATUSBAR(sbar), s_id);
 	}
-	return (g_utf8_validate (dvfd->content, -1, NULL)) ? 
-		dvfd->content : NULL;
-}	
+	return (g_utf8_validate (dvfd->content, -1, NULL)) ? dvfd->content : NULL;
+}
 
 static gchar *
 dv_make_utf8 (gchar * string)
@@ -773,8 +857,7 @@ dv_make_utf8 (gchar * string)
 	value = g_locale_to_utf8 (string, -1, NULL, NULL, NULL);
 	if (!value)
 	{
-		value = g_convert (string, -1, "UTF-8", "ISO-8859-15",
-			NULL, NULL, NULL);
+		value = g_convert (string, -1, "UTF-8", "ISO-8859-15", NULL, NULL, NULL);
 		if (!value)
 			return NULL;
 		return value;
@@ -794,7 +877,7 @@ dv_get_content_length (DVContents * deb)
 		g_hash_table_lookup (deb->data_files, file);
 	if (!dvfd)
 		return 0;
-	return dvfd->size;	
+	return dvfd->size;
 }
 
 gpointer
@@ -812,13 +895,11 @@ dv_get_raw_content (DVContents * deb)
 	if (!dvfd)
 		return NULL;
 	sbar = lookup_widget(deb->parent, "dvstatusbar");
-	s_id = gtk_statusbar_get_context_id (GTK_STATUSBAR(sbar), 
-		"errors");
+	s_id = gtk_statusbar_get_context_id (GTK_STATUSBAR(sbar), "errors");
 	gtk_statusbar_pop (GTK_STATUSBAR(sbar), s_id);
 	if (dvfd->size == 0)
 	{
-		gtk_statusbar_push (GTK_STATUSBAR(sbar), s_id,
-			_("Empty file."));
+		gtk_statusbar_push (GTK_STATUSBAR(sbar), s_id, _("Empty file."));
 		return NULL;
 	}
 	return (gpointer)dvfd->content;
@@ -840,13 +921,11 @@ dv_get_data_content (const gchar * file, GtkWidget * widget)
 	if (!dvfd)
 		return NULL;
 	sbar = lookup_widget(GTK_WIDGET(widget), "dvstatusbar");
-	s_id = gtk_statusbar_get_context_id (GTK_STATUSBAR(sbar), 
-		"errors");
+	s_id = gtk_statusbar_get_context_id (GTK_STATUSBAR(sbar), "errors");
 	gtk_statusbar_pop (GTK_STATUSBAR(sbar), s_id);
 	if (dvfd->size == 0)
 	{
-		gtk_statusbar_push (GTK_STATUSBAR(sbar), s_id,
-			_("Empty file."));
+		gtk_statusbar_push (GTK_STATUSBAR(sbar), s_id, _("Empty file."));
 		return NULL;
 	}
 	check = dv_make_utf8((gchar*)dvfd->content);
