@@ -2,7 +2,7 @@
  *            main.c
  *
  *  Sat Jul 29 14:14:52 2006
- *  Copyright  2006  Neil Williams
+ *  Copyright  2006, 2007  Neil Williams
  *  linux@codehelp.co.uk
  *******************************************************************/
 /*
@@ -26,6 +26,7 @@
 #endif
 
 #include <gnome.h>
+#include <libgnomevfs/gnome-vfs.h>
 #include <glib/gstdio.h>
 #include <archive.h>
 #include "dvarchive.h"
@@ -62,8 +63,10 @@ main (int argc, char *argv[])
 	gchar **remaining_args;
 	GOptionContext *option_context;
 	GnomeProgram *dv;
-	struct stat statinfo;
-	gint stat_val;
+	GtkDialog *dialog;
+	GnomeVFSFileInfo *vfsinfo;
+	GnomeVFSResult vfsresult;
+
 	GOptionEntry option_entries[] = {
 		/* option that collects filenames */
 		{G_OPTION_REMAINING, 0, 0, G_OPTION_ARG_FILENAME_ARRAY,
@@ -82,11 +85,9 @@ main (int argc, char *argv[])
 	g_option_context_add_main_entries (option_context,
 		option_entries, GETTEXT_PACKAGE);
 	dv = gnome_program_init (PACKAGE, VERSION, LIBGNOMEUI_MODULE,
-		argc, argv,
-		GNOME_PARAM_HUMAN_READABLE_NAME, _(GETTEXT_PACKAGE),
+		argc, argv, GNOME_PARAM_HUMAN_READABLE_NAME, _(GETTEXT_PACKAGE),
 		GNOME_PARAM_APP_DATADIR, PACKAGE_DATA_DIR,
-		GNOME_PARAM_GOPTION_CONTEXT, option_context, 
-		GNOME_PARAM_NONE);
+		GNOME_PARAM_GOPTION_CONTEXT, option_context, GNOME_PARAM_NONE);
 	add_pixmap_directory (PACKAGE_PIXMAP_DIR);
 	subwindows = NULL;
 	if (!preview_init ())
@@ -96,6 +97,7 @@ main (int argc, char *argv[])
 	if (remaining_args != NULL)
 	{
 		gint i, num_args;
+		gchar * debfile;
 
 		num_args = g_strv_length (remaining_args);
 		for (i = 0; i < num_args; ++i)
@@ -106,14 +108,48 @@ main (int argc, char *argv[])
 			context = dv_create();
 			window1 = GTK_WINDOW(create_deb_gview_window ());
 			g_return_val_if_fail (window1, EXIT_FAILURE);
-			g_object_set_data (G_OBJECT(window1), 
-				DVCONTENTS, context);
+			g_object_set_data (G_OBJECT(window1), DVCONTENTS, context);
 			set_dv_parent (GTK_WIDGET(window1));
-	        stat_val = g_stat (remaining_args[i],  &statinfo);
-       		if (S_ISREG (statinfo.st_mode) || statinfo.st_size > 0)
-				set_deb_file (g_strdup (remaining_args[i]), context);
-			gtk_widget_show (GTK_WIDGET(window1));
-			subwindows = g_list_append (subwindows, window1);
+			vfsinfo = gnome_vfs_file_info_new ();
+			debfile = g_strdup (remaining_args[i]);
+			vfsresult = gnome_vfs_get_file_info (debfile, vfsinfo, 
+				GNOME_VFS_FILE_INFO_DEFAULT);
+			if (vfsinfo->type == GNOME_VFS_FILE_TYPE_UNKNOWN)
+			{
+				/* relative locations seem to cause trouble with VFS */
+				gchar * cwd = g_strconcat (g_get_current_dir(), "/", NULL);
+				g_free (debfile);
+				debfile = gnome_vfs_uri_make_full_from_relative (cwd, 
+					remaining_args[i]);
+				g_free (cwd);
+				/* refresh info for the new location */
+				vfsresult = gnome_vfs_get_file_info (debfile, vfsinfo, 
+					GNOME_VFS_FILE_INFO_DEFAULT);
+			}
+			if ((vfsinfo->type == GNOME_VFS_FILE_TYPE_REGULAR) &&
+				(vfsinfo->size > 0))
+			{
+				if (g_str_has_suffix(debfile, ".changes"))
+					dv_parse_changes(debfile);
+				else
+				{
+					set_deb_file (debfile, context);
+					gtk_widget_show (GTK_WIDGET(window1));
+					subwindows = g_list_append (subwindows, window1);
+				}
+			}
+			else
+			{
+				dialog = GTK_DIALOG (gtk_message_dialog_new (window1,
+						GTK_DIALOG_DESTROY_WITH_PARENT,	GTK_MESSAGE_ERROR,
+						GTK_BUTTONS_CLOSE, _("Error loading file '%s'."),
+						remaining_args[i]));
+				gtk_dialog_run (dialog);
+				gtk_widget_destroy (GTK_WIDGET (dialog));
+				gtk_widget_show (GTK_WIDGET(window1));
+				subwindows = g_list_append (subwindows, window1);
+			}
+			gnome_vfs_file_info_unref (vfsinfo);
 		}
 		g_strfreev (remaining_args);
 		remaining_args = NULL;
